%Finging p_11 and p_12

p_o = 100000;       %pressure at outlet
p_i = 10e5;         %inlet pressure
eta = 0.28;         %(dynamic) viscosity
r_t = 0.00025;      %pipe radius 0.25mm
r_cyl = 0.000175;   %radius of cylindre constriction, 2r_cyl = 0.35mm
d = 0.0015;          %length of the magnetic field interaction  1.5mm
l_21 = 0.001;   %see figure 1mm
l_22 = l_21;
l_n = 0.008;    %"nozzle" length
l_ic = 0.0002;  %length of inlet constriction 0.2mm
r_ic = 0.00005;   %radius of inlet constriction, 2r_ic = 0.1mm
R_ic1 = (12*eta*l_ic)/(pi*(r_ic^4));
R_ic2 = R_ic1;
R_i1 = (12*eta*0.008)/(pi*(r_t^4)); %longer pipes...
R_i2 = R_i1;
x = 0:0.0001:0.008;

H_pm = 80000;      %preload made by the Permanent magnet (constand and equal on both sides) 
H1 = 0;
H2 = 160000;
k_tau=0.3;          %yield stress proportionality constant
tau_y1 = k_tau*H1;     %yield stress at pipe 1
tau_y2 = k_tau*H2;     %yield stress at pipe 2

den = pi*(r_t^2-r_cyl^2)*(r_t-r_cyl)^2;
R_p1 = R_ic1+R_i1+ (12*eta*d)/(pi*(r_t^4)) + (12*eta*(l_21+l_n-x))/(pi*(r_t^4)) + (12*eta*x)/(den);
R_p2 = R_ic2+R_i2+ (12*eta*d)/(pi*(r_t^4)) + (12*eta*(l_22+x))/(pi*(r_t^4)) + (12*eta*(l_n-x))/(den);
Q1 = (p_i-p_o-(3*tau_y1*(d/r_t)))./(R_p1);
Q2 = (p_i-p_o-(3*tau_y2*(d/r_t)))./(R_p2);

p_11 = Q1.*((12*eta*d)/(pi*(r_t^4)) + (12*eta*(l_21+l_n-x))/(pi*(r_t^4)) + (12*eta.*x)./(den)) + 3*tau_y1*(d/r_t) + p_o;
p_12 = Q2.*((12*eta*d)/(pi*(r_t^4)) + (12*eta*(l_22+x))/(pi*(r_t^4)) + (12*eta*(l_n-x))/(den)) + 3*tau_y2*(d/r_t) + p_o;
dP3 = p_12-p_11;

A_p = (pi*0.002^2)-(pi*0.0005^2);
F3 = dP3*A_p;

dx = x-0.004;

% figure(1)
% subplot(2,1,1)
% plot(dx,F1)
% hold on
% grid on
% plot(dx,F2,'r')
% plot(dx,F3,'g')
% hold off
% title('Plot of the force versus the displacement of the piston, H_1 = 0, H_2 = 160000A/m')
% xlabel('\Delta x [m]')
% ylabel('F [N]')
% legend('2r_c_y_l = 0.15mm','2r_c_y_l = 0.25mm','2r_c_y_l = 0.35mm')
% %xlim([0,5e-4])
% subplot(2,1,2)
% plot(dx,dP1)
% hold on
% grid on
% plot(dx,dP2,'r')
% plot(dx,dP3,'g')
% hold off
% title('Plot of the differential pressure versus the displacement of the piston')
% xlabel('\Delta x [m]')
% ylabel('\Delta P [Pa]')
% legend('2r_c_y_l = 0.15mm','2r_c_y_l = 0.25mm','2r_c_y_l = 0.35mm')
% %xlim([0,5e-4])


%%%%%%%%%%%%%%%%%%%%
% %First: p_i = 10e5 
% figure(2)
% subplot(3,1,1)
% plot(dx,dP1)
% grid on
% hold on
% plot(dx,dP2,'--r')
% plot(dx,dP3,'-.k')
% hold off
% xlabel('\Delta x [m]')
% ylabel('\Delta P [Pa]')
% title('Displacement \Delta x, P_i = 10e5 Pa')
% legend('2r_c_y_l=0.15mm','2r_c_y_l = 0.25mm','2r_c_y_l = 0.35mm')
% 
% %Then: p_i = 20e5
% subplot(3,1,2)
% plot(dx,dP4)
% grid on
% hold on
% plot(dx,dP5,'--r')
% plot(dx,dP6,'-.k')
% hold off
% xlabel('\Delta x [m]')
% ylabel('\Delta P [Pa]')
% title('P_i = 20e5 Pa')
% %legend('2r_c_y_l=0.15mm','2r_c_y_l = 0.25mm','2r_c_y_l = 0.35mm')
% 
% %Then: p_i = 30e5
% subplot(3,1,3)
% plot(dx,dP7)
% grid on
% hold on
% plot(dx,dP8,'--r')
% plot(dx,dP9,'-.k')
% hold off
% xlabel('\Delta x [m]')
% ylabel('\Delta P [Pa]')
% title('P_i = 30e5 Pa')
% %legend('2r_c_y_l=0.15mm','2r_c_y_l = 0.25mm','2r_c_y_l = 0.35mm')


%%%%%Next: Movement for certain electromagnetic coil magnetic field
%%%%%intensity
Hel = 0:5000:80000;
Hel1 = 0:1000:40000;
dx015 = (1.5e-6)*Hel1;
dx025 = (4.5e-7)*Hel;
dx035 = (1.25e-7)*Hel;

figure(3)
plot(Hel1,dx015)
hold on
grid on
plot(Hel,dx025,'--r')
plot(Hel,dx035,'-.k')
xlabel('H_e_l [A/m]')
ylabel('\Delta x [m]')
title('Dynamic simulation, displacement \Delta x from centre position')
legend('2r_c_y_l = 0.15mm','2r_c_y_l = 0.25mm','2r_c_y_l = 0.35mm')

