%Real tests, inner pipe diameter 3mm


%First of all - theoretical model with field
Bmod = 0:0.001:0.055;

dP = 196133;    %Pa, equal to 2.0kg/cm^2 
r = 0.0015;     %pipe radius, (inner diameter 3mm)
eta = 0.28;     %(dynamic) viscosity
L1 = 0.0894;    %pipe length (found through experiments...)
L2 = 0.01;      %magnetic field influence length (1cm diam magnets)
h = r;          
mu = 2e-5;      %fluid permeability for fields under 200mT?
H = Bmod/mu;       %magnetic field intensity
k_tau = 0.52;
tau_y = k_tau*H; % + 2000;   %from graph, valid up to about H = 50 000A/m

mufit = 3e-6;
Hfit = Bmod/mufit;       %magnetic field intensity
tau_yfit = k_tau*Hfit; %+ 2000;   %from graph, valid up to about H = 50 000A/m
%Mogleg grunn til at permeabiliteten er mykje mindre: Drleg blanding?

Qmagn = (dP*pi*(r^4))/(12*eta*L1) - (3*L2*pi*r^4*tau_y)./(h*12*eta*L1);

Qmagnfit = (dP*pi*(r^4))/(12*eta*L1) - (3*L2*pi*r^4*tau_yfit)./(h*12*eta*L1);

Tstar = (pi*r^3*tau_y)/(12*Qmagn*eta)

%Then - theoretical model without field (Poiseuille's law)
dP2 = 0:0.1:2.5; %pressure in kg/cm^2
dPPa = dP2*98066.5;  %from kg/cm^2 to Pa

Qwof = (dPPa*pi*r^4)/(12*eta*L1);    %Poiseuille's law
%12 - perfekt match! 8 not that good


%First: Without magnets
p_i = [0, 0.5, 1, 1.5, 2, 2.5]; %Inlet pressure in kg/cm^2
Qav = [0, 2.352e-6, 5.103e-6, 8.15e-6, 10.38e-6, 12.28e-6]; %average flow rate in m^3/s. The first measurement is not included
Q05 = [2.105e-6,2.454e-6,2.498e-6]; %the flow rates at 0.5kg/cm^3
Q10 = [5e-6,5e-6,5.309e-6]; %flow rates at 1.0kg/cm^3
Q15 = [8e-6,8.163e-6,8.287e-6];
Q20 = [10e-6,10.53e-6,10.62e-6];
Q25 = [11.76e-6,12.5e-6,12.58e-6];

Qlinp = 5.0589e-6*p_i + 5.3857e-8;   %linear approximation to the average flow rate (calculator regression)

figure(1)
subplot(3,1,1)
plot(p_i,Qav)
hold on
plot(p_i,Qlinp,':r')
plot(dP2,Qwof,'--g')
plot(0.5,Q05,'xb')
plot(0.5,1.618e-6,'.')  %discarded
plot(1,Q10,'xb')
plot(1,3.775e-6,'.')    %discarded
plot(1.5,Q15,'xb')
plot(1.5,7.079e-6,'.')  %discarded
plot(2,Q20,'xb')
plot(2,7.551e-6,'.')    %discarded
plot(2.5,Q25,'xb')
plot(2.5,11.33e-6,'.')  %discarded
hold off
xlabel('Supply pressure p_i [kg/cm^2]')
ylabel('Flow rate Q [m^3/s]')
title('Test with changing supply pressure, without magnetic field. Dots discarded')
legend('Average flow rate','Linear approximation','Theoretical model')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%With magnets. Supply pressure 2.0 kg/cm^2
B = [0,11.64e-3,21.65e-3,30.65e-3,36.65e-3,48.8e-3,55.35e-3]; %Magnetic field [T]
Qav = [10.38e-6,9.94e-6,6.514e-6,6.241e-6,4.581e-6,1.918e-6,0.755e-6];   %average flow rate m^3/s (without the first measurement)
Q0 = [10e-6,10.53e-6,10.62e-6];
Q11 = [9.524e-6,10e-6,10.296e-6];   %The flow rates at 11mT
Q21 = [6.452e-6,6.557e-6,6.534e-6];   %The flow rates at 21mT
Q30 = [6.061e-6,6.25e-6,6.411e-6];
Q55 = [0.741e-6,0.769e-6,0.755e-6];
Q36 = [4.444e-6,4.706e-6,4.592e-6];
Q48 = [1.942e-6,1.914e-6,1.898e-6];

Qlin = -1.827e-4*B + 1.1106e-5; %linear approximation to the average flow rate (calculator regression)

%figure(2)
subplot(3,1,2)
plot(B,Qav)
hold on
plot(B,Qlin,':r')
plot(Bmod,Qmagn,'g')
plot(Bmod,Qmagnfit,'--g')
plot(0,Q0,'xb')
plot(0,7.551e-6,'.')    %discarded
plot(11.64e-3,Q11,'xb')
plot(11.64e-3,8.712e-6,'.') %discarded
plot(21.65e-3,Q21,'xb')
plot(21.65e-3,5.663e-6,'.') %discarded
plot(30.65e-3,Q30,'xb')
plot(30.65e-3,5.148e-6,'.')  %discarded
plot(36.65e-3,Q36,'xb')
plot(36.65e-3,3.654e-6,'.') %discarded
plot(48.8e-3,Q48,'xb')
plot(48.8e-3,1.742e-6,'.')  %discarded
plot(55.35e-3,Q55,'xb')
plot(55.35e-3,0.625e-6,'.')  %discarded
hold off
xlabel('Magnetic field [T]')
ylabel('Flow rate Q [m^3/s]')
title('Test with changing magnetic field. Supply pressure 2.0kg/cm^2. Dots discarded')
legend('Average flow rate','Linear approximation','Theoretical model', '\mu = 3e-6')



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Different magnet fields and two different supply pressures
B1 = [0,11.64e-3,21.65e-3,30.65e-3,36.65e-3,48.8e-3,55.35e-3]; %Magnetic field [T]
Qav1 = [10.38e-6,9.94e-6,6.514e-6,6.241e-6,4.581e-6,1.918e-6,0.755e-6];   %average flow rate m^3/s (without the first measurement)
B2 = [0,31.8e-3,53.8e-3,64.1e-3];
Qav2 = [12.28e-6,6.371e-6,2.508e-6,0.860e-6];    %supply pressure 2.5kg/cm^2

Qlin2 = -1.788e-4*B2 + 1.2198e-5;   %linear approximation

%figure(3)
subplot(3,1,3)
plot(B2,Qav2,'--')
hold on
plot(B1,Qav1)
plot(B,Qlin,':r')
plot(B2,Qlin2,':r')
hold off
xlabel('Magnetic field [T]')
ylabel('Average flow rate Q_a_v [m^3/s]')
title('Average flow rates with changing field and two different supply pressures p_i')
legend('p_i = 2.5kg/cm^2','p_i = 2.0kg/cm^2','Linear approximation')



