%Real tests - constriction - inner tube diameter 3mm
%Tests carried out 15.04.2008


%Theoretical model constants (Poiseuille's law):
dP = 196133;    %supply pressure 2.0kg/cm^2
eta = 0.28; %(dynamic) viscosity
L = 0.0894; %total pipe length
r = 0.0015; %pipe radius 1.5mm (diameter 3mm)


%First: Constriction diameter 1.1mm
Lc1 = [0,10.7e-3,16.3e-3,23e-3,30e-3];   %constriction length
rc1 = 5.5e-4;   %constriction radius 0.55mm
rc12 = 6.5e-4;
r_con1 = (r^2-rc1^2)*(r-rc1)^2; 
r_con12 = (r^2-rc12^2)*(r-rc12)^2;
%r_con12 = 1.2e-12;

Q0 = [11.11e-6,10.53e-6,10.96e-6];    %no constriction
Q0d = 10.3e-6;  %discarded
Q10 = [6.061e-6,6.383e-6];   %10.7mm constriction length NBNB! FEIL?
Q10d = 5.148e-6;    %discarded
Q16 = [6.25e-6,6.667e-6,6.534e-6];   %16.3mm constriction length
Q16d = 5.148e-6;    %discarded
Q23 = [5.263e-6,5.660e-6,5.858e-6];   %23mm constr
Q23d = 5.148e-6;    %discarded
Q30 = [4.762e-6,5.172e-6,5.393e-6];   %30mm constr
Q30d = 4.530e-6;    %discarded

Lc1m = 0:0.001:0.03;
Qmod1 = (dP*pi*r^4*r_con1)./(12*eta*r_con1*(L-Lc1m)+12*eta*Lc1m.*r^4);   %theoretical model
Qmod12 = (dP*pi*r^4*r_con12)./(12*eta*r_con12*(L-Lc1m)+12*eta*Lc1m.*r^4);   %theoretical model


%Then: constriction diameter 1.9mm
Lc2 = [0,8.3e-3,17.5e-3,24e-3,30e-3];   %constriction length
rc2 = 9.5e-4;   %constriction radius 0.95mm
rc22 = 10e-4;
r_con2 = (r^2-rc2^2)*(r-rc2)^2;
r_con22 = (r^2-rc22^2)*(r-rc22)^2;
%r_con22 = 3.2e-13;

Qav2 = [10.867e-6,4.007e-6,2.542e-6,2.11e-6,1.891e-6];   %average flow rate
Q8 = [3.774e-6,4e-6,4.247e-6];    %8.3mm constriction length
Q8d = 3.775e-6; %discarded
Q17 = [2.532e-6,2.5e-6,2.594e-6];   %17.5mm constriction length
Q17d = 2.311e-6;    %discarded
Q24 = [2.106e-6,2.073e-6,2.151e-6];   %24mm constr
Q24d = 2.137e-6;    %discarded
Q30mm = [1.786e-6,1.923e-6,1.964e-6]; %30mm constr
Q30mmd = 1.552e-6;  %discarded

Lc2m = 0:0.001:0.03;
Qmod2 = (dP*pi*r^4*r_con2)./(12*eta*r_con2*(L-Lc2m)+12*eta*Lc2m.*r^4);   %theoretical model
Qmod22 = (dP*pi*r^4*r_con22)./(12*eta*r_con22*(L-Lc2m)+12*eta*Lc2m.*r^4);   %theoretical mode

figure(1)
subplot(2,1,1)
plot(Lc1m,Qmod1,'g')
hold on
grid on
plot(Lc1m,Qmod12,'--g')
plot(0,Q0,'bx')
plot(0,Q0d,'b.')    %discarded
plot(10.7e-3,Q10,'bx')
plot(10.7e-3,Q10d,'b.') %discarded
plot(16.3e-3,Q16,'bx')
plot(16.3e-3,Q16d,'b.') %discarded
plot(23e-3,Q23,'bx')
plot(23e-3,Q23d,'b.')   %discarded
plot(30e-3,Q30,'bx')
plot(30e-3,Q30d,'b.')   %discarded
hold off
title('Constriction diameter 1.1mm and supply pressure 2.0kg/cm^2')
xlabel('Length of constriction, L_c [m]')
ylabel('Flow rate [m^3/s]')
legend('Theoretical model, 2r_c_y_l = 1.1mm', '2r_c_y_l = 1.3mm','Test results')

subplot(2,1,2)
%plot(Lc2,Qav2,':b')
plot(Lc2m,Qmod2,'g')
hold on
grid on
plot(Lc2m,Qmod22,'--g')
plot(0,Q0,'bx')
plot(0,Q0d,'b.')    %discarded
plot(8.3e-3,Q8,'bx')
plot(8.3e-3,Q8d,'b.')   %discarded
plot(17.5e-3,Q17,'bx')
plot(17.5e-3,Q17d,'b.') %discarded
plot(24e-3,Q24,'bx')
plot(24e-3,Q24d,'b.')   %discarded
plot(30e-3,Q30mm,'bx')
plot(30e-3,Q30mmd,'b.') %discarded
hold off
title('Constriction diameter 1.9mm and supply pressure 2.0kg/cm^2')
xlabel('Length of constriction, L_c [m]')
ylabel('Flow rate [m^3/s]')
legend('Theoretical model, 2r_c_y_l = 1.9mm','2r_c_y_l = 2mm','Test results')

